==> cscec5b-sync-impl-3.0.0-20210415.021844-47-sources.jar: com/ejianc/business/sync/bean/BuckleDetail.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import org.apache.commons.lang3.builder.ReflectionToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.io.Serializable;
import java.math.BigDecimal;

@TableName("HN_JIEKOU.WJHN_BUCKLEDETAIL") // 合同外用工转扣明细
public class BuckleDetail {
    private static final long serialVersionUID = 1L;
    @TableId("PK_BUCKLEDETAIL")
    private String pkBuckleDetail; //主键 CHAR(20) 20
    @TableField("DDEDUCTDATE")
    private String dDeductDate; //扣款日期 CHAR(10) 10 是
    @TableField("BISSETTLE")
    private String bisSettle;// 是否结算 CHAR(1) 1 是
    @TableField("CSRCID")
    private String csrcId;// 来源单据主表主键 CHAR(20) 20 是
    @TableField("CSRCBID")
    private String csrcbId;// 来源单据表体主键 CHAR(20) 20 是
    @TableField("PK_CORP")
    private String pkCorp;//  公司 CHAR(20) 20 是
    @TableField("PK_PROJECT")
    private String pkProject;//  项目 CHAR(20) 20 是
    @TableField("PK_CONTRACTA")
    private String pkContractA;//  分包合同 CHAR(20) 20 是
    private String ts;
    private BigDecimal nsettlesum;  // DECIMAL(20,8)  总价    来源于审核总价
    private BigDecimal nsettleprice;  // DECIMAL(20,8)  单价  来源于审核单价
    private BigDecimal nsettlecount;  //DECIMAL(20,8)  数量  来源于审核数量
    @TableField("VSETTLECOSTITEM")
    private String vSettleCostItem;// 结算费用项 CHAR(100) 100 是
    @TableField("reporter")
    private String reporter;
    @TableField("dmakedate")
    private String dmakedate;

    public String toString() {
        return ReflectionToStringBuilder.toString(this, ToStringStyle.JSON_STYLE);
    }

    public String getPkBuckleDetail() {
        return pkBuckleDetail;
    }

    public void setPkBuckleDetail(String pkBuckleDetail) {
        this.pkBuckleDetail = pkBuckleDetail;
    }

    public String getDDeductDate() {
        return dDeductDate;
    }

    public void setDDeductDate(String dDeductDate) {
        this.dDeductDate = dDeductDate;
    }

    public String getBisSettle() {
        return bisSettle;
    }

    public void setBisSettle(String bisSettle) {
        this.bisSettle = bisSettle;
    }

    public String getCsrcId() {
        return csrcId;
    }

    public void setCsrcId(String csrcId) {
        this.csrcId = csrcId;
    }

    public String getCsrcbId() {
        return csrcbId;
    }

    public void setCsrcbId(String csrcbId) {
        this.csrcbId = csrcbId;
    }

    public String getPkCorp() {
        return pkCorp;
    }

    public void setPkCorp(String pkCorp) {
        this.pkCorp = pkCorp;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getPkContractA() {
        return pkContractA;
    }

    public void setPkContractA(String pkContractA) {
        this.pkContractA = pkContractA;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public BigDecimal getNsettlesum() {
        return nsettlesum;
    }

    public void setNsettlesum(BigDecimal nsettlesum) {
        this.nsettlesum = nsettlesum;
    }

    public BigDecimal getNsettleprice() {
        return nsettleprice;
    }

    public void setNsettleprice(BigDecimal nsettleprice) {
        this.nsettleprice = nsettleprice;
    }

    public BigDecimal getNsettlecount() {
        return nsettlecount;
    }

    public void setNsettlecount(BigDecimal nsettlecount) {
        this.nsettlecount = nsettlecount;
    }

    public String getVSettleCostItem() {
        return vSettleCostItem;
    }

    public void setVSettleCostItem(String vSettleCostItem) {
        this.vSettleCostItem = vSettleCostItem;
    }

    public String getReporter() {
        return reporter;
    }

    public void setReporter(String reporter) {
        this.reporter = reporter;
    }

    public String getDmakedate() {
        return dmakedate;
    }

    public void setDmakedate(String dmakedate) {
        this.dmakedate = dmakedate;
    }
}

==> cscec5b-sync-impl-3.0.1-20221227.020801-21-sources.jar: com/ejianc/business/sync/bean/BuckleDetail.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import org.apache.commons.lang3.builder.ReflectionToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.io.Serializable;
import java.math.BigDecimal;

@TableName("HN_JIEKOU.WJHN_BUCKLEDETAIL") // 合同外用工转扣明细
public class BuckleDetail {
    private static final long serialVersionUID = 1L;
    @TableId("PK_BUCKLEDETAIL")
    private String pkBuckleDetail; //主键 CHAR(20) 20
    @TableField("DDEDUCTDATE")
    private String dDeductDate; //扣款日期 CHAR(10) 10 是
    @TableField("BISSETTLE")
    private String bisSettle;// 是否结算 CHAR(1) 1 是
    @TableField("CSRCID")
    private String csrcId;// 来源单据主表主键 CHAR(20) 20 是
    @TableField("CSRCBID")
    private String csrcbId;// 来源单据表体主键 CHAR(20) 20 是
    @TableField("PK_CORP")
    private String pkCorp;//  公司 CHAR(20) 20 是
    @TableField("PK_PROJECT")
    private String pkProject;//  项目 CHAR(20) 20 是
    @TableField("PK_CONTRACTA")
    private String pkContractA;//  分包合同 CHAR(20) 20 是
    private String ts;
    private BigDecimal nsettlesum;  // DECIMAL(20,8)  总价    来源于审核总价
    private BigDecimal nsettleprice;  // DECIMAL(20,8)  单价  来源于审核单价
    private BigDecimal nsettlecount;  //DECIMAL(20,8)  数量  来源于审核数量
    @TableField("VSETTLECOSTITEM")
    private String vSettleCostItem;// 结算费用项 CHAR(100) 100 是
    @TableField("reporter")
    private String reporter;
    @TableField("dmakedate")
    private String dmakedate;
    @TableField("PK_CONTRACT_B")
    private String pkContractB;
    @TableField("DETAIL_CODE")
    private String detailCode;
    @TableField("DETAIL_NAME")
    private String detailName;

    public String toString() {
        return ReflectionToStringBuilder.toString(this, ToStringStyle.JSON_STYLE);
    }

    public String getPkBuckleDetail() {
        return pkBuckleDetail;
    }

    public void setPkBuckleDetail(String pkBuckleDetail) {
        this.pkBuckleDetail = pkBuckleDetail;
    }

    public String getDDeductDate() {
        return dDeductDate;
    }

    public void setDDeductDate(String dDeductDate) {
        this.dDeductDate = dDeductDate;
    }

    public String getBisSettle() {
        return bisSettle;
    }

    public void setBisSettle(String bisSettle) {
        this.bisSettle = bisSettle;
    }

    public String getCsrcId() {
        return csrcId;
    }

    public void setCsrcId(String csrcId) {
        this.csrcId = csrcId;
    }

    public String getCsrcbId() {
        return csrcbId;
    }

    public void setCsrcbId(String csrcbId) {
        this.csrcbId = csrcbId;
    }

    public String getPkCorp() {
        return pkCorp;
    }

    public void setPkCorp(String pkCorp) {
        this.pkCorp = pkCorp;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getPkContractA() {
        return pkContractA;
    }

    public void setPkContractA(String pkContractA) {
        this.pkContractA = pkContractA;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public BigDecimal getNsettlesum() {
        return nsettlesum;
    }

    public void setNsettlesum(BigDecimal nsettlesum) {
        this.nsettlesum = nsettlesum;
    }

    public BigDecimal getNsettleprice() {
        return nsettleprice;
    }

    public void setNsettleprice(BigDecimal nsettleprice) {
        this.nsettleprice = nsettleprice;
    }

    public BigDecimal getNsettlecount() {
        return nsettlecount;
    }

    public void setNsettlecount(BigDecimal nsettlecount) {
        this.nsettlecount = nsettlecount;
    }

    public String getVSettleCostItem() {
        return vSettleCostItem;
    }

    public void setVSettleCostItem(String vSettleCostItem) {
        this.vSettleCostItem = vSettleCostItem;
    }

    public String getReporter() {
        return reporter;
    }

    public void setReporter(String reporter) {
        this.reporter = reporter;
    }

    public String getDmakedate() {
        return dmakedate;
    }

    public void setDmakedate(String dmakedate) {
        this.dmakedate = dmakedate;
    }

    public String getPkContractB() {
        return pkContractB;
    }

    public void setPkContractB(String pkContractB) {
        this.pkContractB = pkContractB;
    }

    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
}
